package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYqxxlnum;
import com.ruoyi.tcZz.service.ITcYqxxlnumService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 舆情信息量统计Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/yqxxlnum")
public class TcYqxxlnumController extends BaseController
{
    @Autowired
    private ITcYqxxlnumService tcYqxxlnumService;

    /**
     * 查询舆情信息量统计列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqxxlnum:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYqxxlnum tcYqxxlnum)
    {
        startPage();
        List<TcYqxxlnum> list = tcYqxxlnumService.selectTcYqxxlnumList(tcYqxxlnum);
        return getDataTable(list);
    }

    /**
     * 导出舆情信息量统计列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqxxlnum:export')")
    @Log(title = "舆情信息量统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqxxlnum tcYqxxlnum)
    {
        List<TcYqxxlnum> list = tcYqxxlnumService.selectTcYqxxlnumList(tcYqxxlnum);
        ExcelUtil<TcYqxxlnum> util = new ExcelUtil<TcYqxxlnum>(TcYqxxlnum.class);
        util.exportExcel(response, list, "舆情信息量统计数据");
    }

    /**
     * 获取舆情信息量统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqxxlnum:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqxxlnumService.selectTcYqxxlnumById(id));
    }

    /**
     * 新增舆情信息量统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqxxlnum:add')")
    @Log(title = "舆情信息量统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYqxxlnum tcYqxxlnum)
    {
        return toAjax(tcYqxxlnumService.insertTcYqxxlnum(tcYqxxlnum));
    }

    /**
     * 修改舆情信息量统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqxxlnum:edit')")
    @Log(title = "舆情信息量统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqxxlnum tcYqxxlnum)
    {
        return toAjax(tcYqxxlnumService.updateTcYqxxlnum(tcYqxxlnum));
    }

    /**
     * 删除舆情信息量统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqxxlnum:remove')")
    @Log(title = "舆情信息量统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqxxlnumService.deleteTcYqxxlnumByIds(ids));
    }
}
