package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYqzs;
import com.ruoyi.tcZz.service.ITcYqzsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 舆情走势图Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Api(tags = "舆情走势图")
@RestController
@RequestMapping("/tcZz/netWorkYq/yqzs")
public class TcYqzsController extends BaseController
{
    @Autowired
    private ITcYqzsService tcYqzsService;

    /**
     * 查询舆情走势图列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqzs:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYqzs tcYqzs)
    {
        startPage();
        List<TcYqzs> list = tcYqzsService.selectTcYqzsList(tcYqzs);
        return getDataTable(list);
    }

    /**
     * 导出舆情走势图列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqzs:export')")
    @Log(title = "舆情走势图", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqzs tcYqzs)
    {
        List<TcYqzs> list = tcYqzsService.selectTcYqzsList(tcYqzs);
        ExcelUtil<TcYqzs> util = new ExcelUtil<TcYqzs>(TcYqzs.class);
        util.exportExcel(response, list, "舆情走势图数据");
    }

    /**
     * 获取舆情走势图详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqzs:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqzsService.selectTcYqzsById(id));
    }

    /**
     * 新增舆情走势图
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqzs:add')")
    @Log(title = "舆情走势图", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYqzs tcYqzs)
    {
        return toAjax(tcYqzsService.insertTcYqzs(tcYqzs));
    }

    /**
     * 修改舆情走势图
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqzs:edit')")
    @Log(title = "舆情走势图", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqzs tcYqzs)
    {
        return toAjax(tcYqzsService.updateTcYqzs(tcYqzs));
    }

    /**
     * 删除舆情走势图
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqzs:remove')")
    @Log(title = "舆情走势图", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqzsService.deleteTcYqzsByIds(ids));
    }

    /**
     * 查询舆情走势图列表
     */
 @ApiOperation(value = "查询舆情走势图列表",response =TcYqzs.class )
    @GetMapping("/ListNoToken")
    public TableDataInfo ListNoToken(TcYqzs tcYqzs)
    {
        startPage();
        List<TcYqzs> list = tcYqzsService.selectTcYqzsList(tcYqzs);
        return getDataTable(list);
    }
}
