package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZdqyml;
import com.ruoyi.tcZz.service.ITcZdqymlService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 重点企业名录Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netManage/zdqyml")
public class TcZdqymlController extends BaseController
{
    @Autowired
    private ITcZdqymlService tcZdqymlService;

    /**
     * 查询重点企业名录列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdqyml:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcZdqyml tcZdqyml)
    {
        startPage();
        List<TcZdqyml> list = tcZdqymlService.selectTcZdqymlList(tcZdqyml);
        return getDataTable(list);
    }

    /**
     * 导出重点企业名录列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdqyml:export')")
    @Log(title = "重点企业名录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZdqyml tcZdqyml)
    {
        List<TcZdqyml> list = tcZdqymlService.selectTcZdqymlList(tcZdqyml);
        ExcelUtil<TcZdqyml> util = new ExcelUtil<TcZdqyml>(TcZdqyml.class);
        util.exportExcel(response, list, "重点企业名录数据");
    }

    /**
     * 获取重点企业名录详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdqyml:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZdqymlService.selectTcZdqymlById(id));
    }

    /**
     * 新增重点企业名录
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdqyml:add')")
    @Log(title = "重点企业名录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcZdqyml tcZdqyml)
    {
        return toAjax(tcZdqymlService.insertTcZdqyml(tcZdqyml));
    }

    /**
     * 修改重点企业名录
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdqyml:edit')")
    @Log(title = "重点企业名录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcZdqyml tcZdqyml)
    {
        return toAjax(tcZdqymlService.updateTcZdqyml(tcZdqyml));
    }

    /**
     * 删除重点企业名录
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:zdqyml:remove')")
    @Log(title = "重点企业名录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZdqymlService.deleteTcZdqymlByIds(ids));
    }
}
